function res=point_milieuc(a,b,m,fun,varargin)
%
% res=point_milieuc (a,b,m,fun,varargin)
%   
% Computes the integral of fun between a and b, using the point milieu's rule.
%
% >> INPUT <<
%
%  [a, b]     extremes of the interval
%  m          number of subintervals
%  fun        function to be integrated in [a,b]
%  varargin   additional variables of function fun
%             Warning, integration of function fun with respect to first
%             variable of function fun
%
% >> OUTPUT <<
%
%  res : value of the integral
%
% >> Examples <<
%
%  I_pm = point_milieuc (0,1,100,@sin);
%  I_pm = point_milieuc (0,1,100,'sin');
%  I_pm = point_milieuc (0,1,100,'F') provided a function F.m
%  I_pm = point_milieuc (0,1,100,'F',a,b) provided a function F.m, where F
%  has three variables x, a and b.
%  I_pm = simpsonc(0,1,100,@F,a,b) provided a function F.m, where F
%  has three variables x, a and b.
%  I_pm = point_milieuc (0,1,100,'atan2',1) 

h=(b-a)/m;
x=a+h/2:h:b-h/2;
res=h*sum(feval(fun,x,varargin{:}));